Module ArbGasInfo

Module ArbGasInfo 

Module containing a contract’s types and functions.

interface ArbGasInfo {
    function getPricesInWei() external view returns (uint256 perL2Tx, uint256 perL1CalldataUnit, uint256 perStorageUnit, uint256 perArbGas, uint256 perL1Surplus, uint256 baseFee);
    function getL1BaseFeeEstimate() external view returns (uint256);
}

Structs

ArbGasInfoInstance
A ArbGasInfo instance.
getL1BaseFeeEstimateCall
Function with signature getL1BaseFeeEstimate() and selector 0xf5d6ded7.
getL1BaseFeeEstimateReturn
Container type for the return parameters of the getL1BaseFeeEstimate() function.
getPricesInWeiCall
Function with signature getPricesInWei() and selector 0x41b247a8.
getPricesInWeiReturn
Container type for the return parameters of the getPricesInWei() function.

Enums

ArbGasInfoCalls
Container for all the ArbGasInfo function calls.

Functions

new
Creates a new wrapper around an on-chain ArbGasInfo contract instance.