Module OpGasPriceOracle

Module OpGasPriceOracle 

Module containing a contract’s types and functions.

interface OpGasPriceOracle {
    function l1BaseFee() external view returns (uint256);
    function getL1Fee(bytes _data) external view returns (uint256);
}

Structs

OpGasPriceOracleInstance
A OpGasPriceOracle instance.
getL1FeeCall
Function with signature getL1Fee(bytes) and selector 0x49948e0e.
getL1FeeReturn
Container type for the return parameters of the getL1Fee(bytes) function.
l1BaseFeeCall
Function with signature l1BaseFee() and selector 0x519b4bd3.
l1BaseFeeReturn
Container type for the return parameters of the l1BaseFee() function.

Enums

OpGasPriceOracleCalls
Container for all the OpGasPriceOracle function calls.

Functions

new
Creates a new wrapper around an on-chain OpGasPriceOracle contract instance.