decode_packed_values

Function decode_packed_values 

pub fn decode_packed_values(data: &[u8], expected: usize) -> Option<Vec<U256>>
Decode extractor return data (packed 32-byte words) into values.

Returns None when the payload is not exactly expected words — the signature of a call that did not actually execute the extractor (e.g. a provider that ignored the code override, or a precompile target).