Module IERC20

Module IERC20 

Module containing a contract’s types and functions.

contract IERC20 {
    function balanceOf(address target) returns (uint256);
    function decimals() returns (uint8);
    function allowance(address owner, address spender) returns (uint256);
}

Structs

IERC20Instance
A IERC20 instance.
allowanceCall
Function with signature allowance(address,address) and selector 0xdd62ed3e.
allowanceReturn
Container type for the return parameters of the allowance(address,address) function.
balanceOfCall
Function with signature balanceOf(address) and selector 0x70a08231.
balanceOfReturn
Container type for the return parameters of the balanceOf(address) function.
decimalsCall
Function with signature decimals() and selector 0x313ce567.
decimalsReturn
Container type for the return parameters of the decimals() function.

Enums

IERC20Calls
Container for all the IERC20 function calls.

Functions

new
Creates a new wrapper around an on-chain IERC20 contract instance.