pub enum MissingTargetBehavior {
Error,
Create,
}Expand description
Behavior when overriding code at a target account that is not known to the cache/backend.
Variants
Error
Return an error if the target account cannot be loaded.
Create
Create a default account with the replacement code.