#[non_exhaustive]pub enum PreparedStoragePatchError {
DuplicateSlot {
address: Address,
slot: U256,
},
BaselineMismatch {
prepared: B256,
cache: Option<B256>,
},
}Expand description
Invalid worker-produced storage patch.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DuplicateSlot
The artifact contains multiple values for one storage identity.
BaselineMismatch
The actor cache is no longer pinned to the artifact’s exact block hash.