#[non_exhaustive]pub enum StorageRoundFetchError {
DuplicateRequest {
address: Address,
slot: U256,
},
UnexpectedResult {
address: Address,
slot: U256,
},
DuplicateResult {
address: Address,
slot: U256,
},
MissingResult {
address: Address,
slot: U256,
},
}Expand description
Invalid storage-round request or malformed provider response.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DuplicateRequest
The same identity appeared more than once across verify/probe work.
UnexpectedResult
The provider returned an identity that was not requested.
DuplicateResult
The provider returned the same identity more than once.
MissingResult
The provider omitted a requested identity.