pub struct StorageRoundFetch { /* private fields */ }Expand description
Complete, non-mutating result of one storage-only provider round.
Implementations
Sourceimpl StorageRoundFetch
impl StorageRoundFetch
Sourcepub const fn block_hash(&self) -> B256
pub const fn block_hash(&self) -> B256
Exact hash used by the provider read.
Sourcepub fn verified(&self) -> &[SlotOutcome]
pub fn verified(&self) -> &[SlotOutcome]
One classified outcome per verify request, in request order.
Sourcepub fn probed(&self) -> &[SlotOutcome]
pub fn probed(&self) -> &[SlotOutcome]
One classified outcome per probe request, in request order.
Sourcepub const fn patch(&self) -> &PreparedStoragePatch
pub const fn patch(&self) -> &PreparedStoragePatch
Successfully fetched verify values ready for atomic cache-owner commit.
Sourcepub fn into_patch(self) -> PreparedStoragePatch
pub fn into_patch(self) -> PreparedStoragePatch
Consume the result and return its prepared commit patch.
Sourcepub fn into_parts(
self,
) -> (Vec<SlotOutcome>, Vec<SlotOutcome>, PreparedStoragePatch)
pub fn into_parts( self, ) -> (Vec<SlotOutcome>, Vec<SlotOutcome>, PreparedStoragePatch)
Consume the result without cloning planner outcomes or prepared values.