pub fn decode_revert_reason(data: &Bytes) -> RevertReasonExpand description
Decode revert data using only the standard Solidity built-ins.
For application-specific custom errors, build a RevertDecoder and call
RevertDecoder::decode.
pub fn decode_revert_reason(data: &Bytes) -> RevertReasonDecode revert data using only the standard Solidity built-ins.
For application-specific custom errors, build a RevertDecoder and call
RevertDecoder::decode.