#[non_exhaustive]pub enum ReactiveBaselineError {
ActiveRuntime,
ConflictingBaseline {
existing_number: u64,
existing_hash: B256,
requested_number: u64,
requested_hash: B256,
},
CacheChainMismatch {
baseline_chain_id: u64,
cache_chain_id: u64,
},
CacheBlockMismatch {
number: u64,
hash: B256,
},
}Expand description
Error adopting an RPC snapshot as a runtime’s canonical continuity baseline.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ActiveRuntime
Runtime or engine delivery state already contains lifecycle work.
ConflictingBaseline
An exact repeat is allowed, but the requested baseline conflicts with the previously adopted block.
Fields
CacheChainMismatch
Typed baseline and cache identify different chains.
Fields
CacheBlockMismatch
The cache is not hash-pinned to the exact adopted canonical block.