#[non_exhaustive]pub enum ResyncFailureKind {
MissingStorageFetcher,
StorageFetchFailed,
StorageFetchOmitted,
MissingAccountFetcher,
AccountFetchFailed,
AccountFetchOmitted,
}Expand description
Stable classification for a failed resync target.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingStorageFetcher
A storage target could not be fetched because no storage batch fetcher is configured.
StorageFetchFailed
The storage batch fetcher returned an error for the requested slot.
StorageFetchOmitted
The storage batch fetcher did not return a result for the requested slot.
MissingAccountFetcher
An account target could not be fetched because no account proof fetcher is configured.
AccountFetchFailed
The account proof fetcher returned an error for the requested address.
AccountFetchOmitted
The account proof fetcher did not return a result for the requested address.