#[non_exhaustive]pub struct FlashblockInvalidation {
pub provider: ProviderRef,
pub payload_id: FixedBytes<8>,
pub reason: FlashblockInvalidationReason,
}Expand description
Observable fail-closed invalidation for one provider generation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.provider: ProviderRefProvider generation whose speculative payload was revoked.
payload_id: FixedBytes<8>Payload identity that was active or could not be trusted.
reason: FlashblockInvalidationReasonContinuity or caller lifecycle transition that caused the revocation.