pub struct ReactiveRuntime<N: Network = Ethereum> { /* private fields */ }Expand description
Reactive runtime.
Implementations
Sourceimpl<N: Network> ReactiveRuntime<N>
impl<N: Network> ReactiveRuntime<N>
Sourcepub fn new(config: ReactiveConfig) -> Self
pub fn new(config: ReactiveConfig) -> Self
Create an empty runtime.
Sourcepub fn register_handler(
&mut self,
handler: Arc<dyn ReactiveHandler<N>>,
) -> Result<(), RegisterError>
pub fn register_handler( &mut self, handler: Arc<dyn ReactiveHandler<N>>, ) -> Result<(), RegisterError>
Register a handler.
Sourcepub fn register_hook(
&mut self,
hook: Arc<dyn ReactiveHook<N>>,
) -> Result<(), RegisterError>
pub fn register_hook( &mut self, hook: Arc<dyn ReactiveHook<N>>, ) -> Result<(), RegisterError>
Register a hook.
Sourcepub fn interests(&self) -> Vec<ReactiveInterest<N>>
pub fn interests(&self) -> Vec<ReactiveInterest<N>>
Return all registered interests in handler registration order.
Sourcepub fn ingest_batch(
&mut self,
cache: &mut EvmCache,
batch: ReactiveInputBatch<N>,
) -> Result<ReactiveBatchReport<N>, ReactiveError>
pub fn ingest_batch( &mut self, cache: &mut EvmCache, batch: ReactiveInputBatch<N>, ) -> Result<ReactiveBatchReport<N>, ReactiveError>
Ingest a batch, apply valid direct state effects, and dispatch reports.
Sourcepub fn ingest_batch_with_resync(
&mut self,
cache: &mut EvmCache,
batch: ReactiveInputBatch<N>,
) -> Result<ReactiveBatchReport<N>, ReactiveError>
pub fn ingest_batch_with_resync( &mut self, cache: &mut EvmCache, batch: ReactiveInputBatch<N>, ) -> Result<ReactiveBatchReport<N>, ReactiveError>
Ingest a batch, then execute surfaced storage resync requests.
This entrypoint preserves ingest_batch behavior for
direct handler effects, then runs a synchronous resync phase over the
collected ResyncRequests. Storage targets are fetched through
EvmCache::storage_batch_fetcher grouped by ResyncBlock, successful
values are applied as StateUpdate::slot updates through
EvmCache::apply_updates, and unsupported or failed targets are reported
in ResyncReport::failed. It does not start subscribers, background
workers, or network transport.